@@ -204,7 +204,7 @@ class Binomial(Distribution):
         
         """
         return "mean {}, standard deviation {}, p {}, n {}".\
-        format(self.mean, self.stdev, self.p, self.n)
+        format(self.mean, self.sd, self.p, self.n)
 
 
 
